# pybiomatx

[![Tests](https://github.com/canatella/pybiomatx/workflows/Tests/badge.svg)](https://github.com/canatella/pybiomatx/actions?query=workflow%3Aci)
[![pypi version](https://img.shields.io/pypi/v/pybiomatx.svg)](https://pypi.org/project/pybiomatx/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)

Python API for managing the Biomatx home automation system

## Requirements

pybiomatx requires Python >=3.9

## Installation

It is recommended to install with `pipx`, if `pipx` haven't been installed yet, refer to the [pipx's docs](https://github.com/pipxproject/pipx)

```bash
$ pipx install biomatx
```

Alternatively, install with `pip` to the user site:

```bash
$ python -m pip install --user biomatx
```
